@@ -14,6 +14,7 @@
 #ifndef LINUX_QUOTA_H
 #define LINUX_QUOTA_H
 
+#include <sys/cdefs.h>
 #include <sys/types.h>
 #include "system.h"
 
@@ -95,6 +96,25 @@ struct old_mem_dqinfo {
   unsigned int dqi_free_entry;
 };
 
+/* According to 'man quotactl' these are defined in sys/quota.h
+   but that seems to not always be the case */
+#ifndef IIF_BGRACE
+#define IIF_BGRACE  1
+#endif
+
+#ifndef IIF_IGRACE
+#define IIF_IGRACE  2
+#endif
+
+#ifndef IIF_FLAGS
+#define IIF_FLAGS   4
+#endif
+
+#ifndef IIF_ALL
+#define IIF_ALL     (IIF_BGRACE | IIF_IGRACE | IIF_FLAGS)
+#endif
+
+
 /* The generic diskinfo-struct: */
 struct if_dqinfo {
   u_int64_t dqi_bgrace;
