@@ -18,5 +18,7 @@
 typedef unsigned long long int u_int64_t;
 #endif
 
-#endif /* INCLUDE_QUOTATOOL */
+/* check for BSD variants */
+#define ANY_BSD (__FreeBSD__ || __FreeBSD_kernel__ || __OpenBSD__ || __NetBSD__)
 
+#endif /* INCLUDE_QUOTATOOL */
