@@ -25,6 +25,9 @@
 struct _fs_t {
   char device[PATH_MAX];
   char mount_pt[PATH_MAX];
+#if PLATFORM_LINUX
+   char mnt_type[PATH_MAX]; /* xfs, reiserfs, ext2 etc */
+#endif /* PLATFORM_LINUX */
 };
 typedef struct _fs_t fs_t;
 
